# Go package for reading temperature and humidity from DHT11, DHT22 and AM2302 sensors on Raspberry Pi

[![License: MIT](https://img.shields.io/badge/License-MIT-blue.svg)](https://opensource.org/licenses/MIT)
[![Go Reference](https://pkg.go.dev/badge/gitfox.ru/victor/dht-exporter.svg)](https://pkg.go.dev/gitfox.ru/victor/dht-exporter)
![DHT Exporter](https://shields.foxteam.ru/badge/DHT_Exporter-v1.0.6-purple)
![Go DHT](https://shields.foxteam.ru/badge/Go_DHT-v1.1.0-darkgreen)
![Go WiringPi](https://shields.foxteam.ru/badge/Go_WiringPi-v1.1.0-901030)
![Last commit](https://shields.foxteam.ru/github/last-commit/chapvic/go-dht)

This package contains only one function for measuring temperature and humidity from DHT11, DHT22 and AM2302 sensors.
The package uses a Go-adapted version of the [WiringPi GPIO Library](https://github.com/WiringPi/WiringPi) - [Go WiringPi](https://gitfox.ru/victor/go-wiringpi)

## Usage example

1. Download and install the [WiringPi GPIO](https://github.com/WiringPi/WiringPi) library on your Raspberry Pi
2. Create a Go file with the following content:

```go
package main

import (
    "fmt"
    "gitfox.ru/victor/go-dht"
)

var (
    pin = 7   // Pin number (GPIO_7)
)

func main() {
    temperature, humidity, err := dht.ReadDHT(pin)
    if err != nil {
        fmt.Println("Read error!")
    } else {
        fmt.Printf("Temperature: &.1f °C\nHumidity: %.1f %%\n", temperature, humidity)
    }
}
```

3. Create a module file, for example, `dht-reader`:

```shell
go mod init dht-reader
```

4. Build the program:
```shell
go get
go build
```

5. Run your application to get the temperature and humidity.

#### Links

- [WiringPi GPIO Library](https://github.com/WiringPi/WiringPi)
- [Go WiringPi Package](https://gitfox.ru/victor/go-wiringpi)
- [Prometheus DHT Exporter](https://gitfox.ru/victor/dht-exporter)
