# Пакет Go для чтения температуры и влажности с датчиков DHT11, DHT22 и AM2302 на Raspberry Pi

[![License: MIT](https://img.shields.io/badge/License-MIT-blue.svg)](https://opensource.org/licenses/MIT)
[![Go Reference](https://pkg.go.dev/badge/gitfox.ru/victor/dht-exporter.svg)](https://pkg.go.dev/gitfox.ru/victor/dht-exporter)
![DHT Exporter](https://shields.foxteam.ru/badge/DHT_Exporter-v1.0.6-purple)
![Go DHT](https://shields.foxteam.ru/badge/Go_DHT-v1.1.0-darkgreen)
![Go WiringPi](https://shields.foxteam.ru/badge/Go_WiringPi-v1.1.0-901030)
![Last commit](https://shields.foxteam.ru/github/last-commit/chapvic/go-dht)

Данный пакет содержит всего одну функцию для чтения температуры и влажности с датчиков DHT11, DHT22 и AM2302.
Для взаимодействия с датчиком используется адаптированная для Go библиотека [Go WiringPi](https://gitfox.ru/victor/go-wiringpi), созданная на базе исходного проекта WiringPi GPIO Library - https://github.com/WiringPi/WiringPi

## Пример использования

1. Загрузите и установите на вашем Raspberry Pi библиотеку [WiringPi GPIO](https://github.com/WiringPi/WiringPi)
2. Создайте файл Go следующего содержания:

```go
package main

import (
    "fmt"
    "gitfox.ru/victor/go-dht"
)

var (
    pin = 7   // Номер пина, к корому подключен датчик (GPIO_7)
)

func main() {
    temperature, humidity, err := dht.ReadDHT(pin)
    if err != nil {
        fmt.Println("Read error!")
    } else {
        fmt.Printf("Temperature: &.1f °C\nHumidity: %.1f %%\n", temperature, humidity)
    }
}
```

3. Создайте файл модуля, например, `dht-reader`:

```shell
go mod init dht-reader
```

4. Выполните сборку программы:
```shell
go get
go build
```

5. В результате будет создано приложение dht-reader, запустив которое вы получите значения температуры и влажности.

#### Ссылки

- [WiringPi GPIO Library](https://github.com/WiringPi/WiringPi)
- [Go WiringPi Package](https://gitfox.ru/victor/go-wiringpi)
- [Prometheus DHT Exporter](https://gitfox.ru/victor/dht-exporter)
